==> client-java-5.1.12.2-sources.jar: com/epam/reportportal/service/logs/LoggingSubscriber.java <==
/*
 *  Copyright 2022 EPAM Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package com.epam.reportportal.service.logs;

import com.epam.ta.reportportal.ws.model.BatchSaveOperatingRS;
import io.reactivex.FlowableSubscriber;
import org.reactivestreams.Subscription;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.annotation.Nonnull;

/**
 * Set of logging subscription for ReportPortal logging client
 */
public final class LoggingSubscriber implements FlowableSubscriber<BatchSaveOperatingRS> {
    private static final Logger LOGGER = LoggerFactory.getLogger(LoggingSubscriber.class);

    @Override
    public void onSubscribe(@Nonnull Subscription s) {
        // ignore
    }

    @Override
    public void onNext(BatchSaveOperatingRS result) {
        // ignore
        result.getResponses().forEach(data -> LOGGER.debug("[{} {} {}] ReportPortal logging debug",
                Thread.currentThread().getId(), data.getMessage(), data.getStackTrace()));
    }

    @Override
    public void onError(Throwable e) {
        LOGGER.error("[{}] ReportPortal logging error", Thread.currentThread().getId(), e);
    }

    @Override
    public void onComplete() {
        // ignore
    }
}

==> client-java-5.1.12.5-sources.jar: com/epam/reportportal/service/logs/LoggingSubscriber.java <==
/*
 *  Copyright 2022 EPAM Systems
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */
package com.epam.reportportal.service.logs;

import com.epam.ta.reportportal.ws.model.BatchSaveOperatingRS;
import io.reactivex.FlowableSubscriber;
import org.reactivestreams.Subscription;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import javax.annotation.Nonnull;

/**
 * Set of logging subscription for ReportPortal logging client
 */
public final class LoggingSubscriber implements FlowableSubscriber<BatchSaveOperatingRS> {
    private static final Logger LOGGER = LoggerFactory.getLogger(LoggingSubscriber.class);

    @Override
    public void onSubscribe(@Nonnull Subscription s) {
        // ignore
    }

    @Override
    public void onNext(BatchSaveOperatingRS result) {
        result.getResponses().forEach(res -> LOGGER.debug("[{}] ReportPortal logging onNext LoggingSubscriber: id " +
                        "[{}]" +
                        " " +
                        "message [{}] error[{}]",
                Thread.currentThread().getId(),
                res.getId(), res.getMessage(), res.getStackTrace()));
    }

    @Override
    public void onError(Throwable e) {
        LOGGER.error("[{}] ReportPortal logging error", Thread.currentThread().getId(), e);
    }

    @Override
    public void onComplete() {
        // ignore
        LOGGER.debug("[{}] ReportPortal logging onComplete LoggingSubscriber", Thread.currentThread().getId());
    }
}
